# crapy

Make python worse

## Install

```bash
pip install crapy
```

## Philosophy

 - Make python worse
 - Standard library rewrites should be as sanely-contrived as possible while still being technically correct


## Contributing

Contributions are welcome, feel free to send pull requests!

